@@ -19,12 +19,15 @@ test_that("plot path works", {
     alpha = 0.4, group_df = group_df, outcome_name = "y", intercept = FALSE,
     group_name = "group_name", var_name = "variable_name",
   )
-  labels(terms(sgb_formula))[[1]]
-  labels(terms(sgb_formula))[[201]]
 
   sgb_model <- mboost(
     formula = sgb_formula, data = df,
     control = boost_control(nu = 1, mstop = 600)
   )
-  plot_path(sgb_model[50])
+  path <- sgboost::get_coef_path(sgb_model[150])
+  plot_path(sgb_model[150])
+  expect_error(
+    plot_path(sgb_model = sgb_model, max_char_length = -1),
+    "max_char_length must be a positive number"
+  )
 })
